.. domutils documentation master file, created by
   sphinx-quickstart on Fri Jun 28 14:27:39 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.
    Indices and tables
    ==================
    
    * :ref:`genindex`
    * :ref:`modindex`
    * :ref:`search`
    
    .. currentmodule:: legs.legs
    .. autofunction:: __init__
    .. autofunction:: plot_data

domutils
================

The package **domutils** provides 3 modules:


.. toctree::
   :caption: Legs 
   :maxdepth: 1

   legsTutorial
   legsDoc
   legsResources

For easy construction of custom color mappings & palettes:


.. toctree::
   :caption: geo_tools
   :maxdepth: 1

   geoDoc

For handling geographical projections of data with arbitrary lat/lon coordinates.

.. toctree::
   :caption: radar_tools
   :maxdepth: 2

   radarTutorialIndex
   radarDoc

To get radar moisaics in various formats and construct accumulations on the fly. 



.. toctree::
   :caption: Gallery

   auto_examples/index


.. toctree::
   :caption: Install

   install


.. toctree::
   :caption: Contribute

   contribute

.. toctree::
   :caption: Acknowledgement

   acknowledgement













